package com.ruoyi.system.service.impl;

import com.ruoyi.common.core.domain.entity.UserHistory;
import com.ruoyi.common.utils.SecurityUtils;
import com.ruoyi.system.mapper.UserHistoryMapper;
import com.ruoyi.system.service.IUserHistoryService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 用户播放历史Service业务层处理
 * 
 * @author ruoyi
 * @date 2025-07-15
 */
@Service
public class UserHistoryServiceImpl implements IUserHistoryService 
{
    @Autowired
    private UserHistoryMapper userHistoryMapper;

    /**
     * 查询用户播放历史
     * 
     * @param id 用户播放历史主键
     * @return 用户播放历史
     */
    @Override
    public UserHistory selectUserHistoryById(String id)
    {
        return userHistoryMapper.selectUserHistoryById(id);
    }

    /**
     * 查询用户播放历史列表
     * 
     * @param userHistory 用户播放历史
     * @return 用户播放历史
     */
    @Override
    public List<UserHistory> selectUserHistoryList(UserHistory userHistory)
    {
        return userHistoryMapper.selectUserHistoryList(userHistory);
    }

    /**
     * 新增用户播放历史
     * 
     * @param userHistory 用户播放历史
     * @return 结果
     */
    @Override
    public int insertUserHistory(UserHistory userHistory)
    {
        return userHistoryMapper.insertUserHistory(userHistory);
    }

    /**
     * 修改用户播放历史
     * 
     * @param userHistory 用户播放历史
     * @return 结果
     */
    @Override
    public int updateUserHistory(UserHistory userHistory)
    {
        return userHistoryMapper.updateUserHistory(userHistory);
    }

    /**
     * 批量删除用户播放历史
     * 
     * @param ids 需要删除的用户播放历史主键
     * @return 结果
     */
    @Override
    public int deleteUserHistoryByIds(String[] ids)
    {
        return userHistoryMapper.deleteUserHistoryByIds(ids);
    }

    /**
     * 删除用户播放历史信息
     * 
     * @param id 用户播放历史主键
     * @return 结果
     */
    @Override
    public int deleteUserHistoryById(String id)
    {
        return userHistoryMapper.deleteUserHistoryById(id);
    }

    @Override
    public int insertHistory(Long userId, String musicId) {
        return 0;
    }

    @Override
    public int deleteUserHistoryByMusicId(String[] musicIds) {
        Long userId = SecurityUtils.getUserId();
        return userHistoryMapper.deleteUserHistoryByMusicId(musicIds,userId);
    }
}
